@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
+  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.  You may
@@ -72,6 +72,9 @@ extern "C" {
 #    define MAGICKCORE_SIZEOF_SSIZE_T 4
 #  endif
 #endif
+#ifndef S_ISCHR
+#  define S_ISCHR(m) (((m) & S_IFMT) == S_IFCHR)
+#endif
 
 #if defined(_MSC_VER)
 # if !defined(MAGICKCORE_MSC_VER)
